@@ -81,10 +81,10 @@ class FirestoreClient(BaseClient):
         doc_ref = collection.document(_id)
         try:
             timestamp = await force_async(doc_ref.delete)()
-            LOG.info(f"User deleted at {timestamp}")
+            LOG.info(f"Record {_id} deleted at {timestamp}")
             return DeleteResult()
         except NotFound as exc:
-            LOG.warning(f"Error deleting user {_id} from firestore, user not found")
+            LOG.warning(f"Error deleting record {_id} from firestore, record not found")
             raise exc
 
     async def update_one(
