@@ -5,21 +5,23 @@ from typing import Any, List, Optional, Tuple
 
 from pydantic import Field, root_validator, validator
 
+from fa_common import CamelModel, DatabaseError, get_now
+from fa_common import logger as LOG
+
 from .utils import get_db_client
-from fa_common import get_now, logger as LOG, DatabaseError, CamelModel
 
 # from pymongo.results import UpdateResult, DeleteResult
 
 
-class DBIndex(CamelModel):
-    pass
-
-
 class SortOrder(str, Enum):
     ASCENDING = "ASCENDING"
     DESCENDING = "DESCENDING"
 
 
+class DBIndex(CamelModel):
+    field_name: str
+
+
 class FireOffset(CamelModel):
     # Start at or Start After
     start_at: bool = False
@@ -74,14 +76,11 @@ class DocumentDBModel(CamelModel, abc.ABC):
             class Meta:
                 collection = "mymodel_collection"
 
-
         mymodel = MyModel(additional_field1="value")
         mymodel.save()
-
         assert mymodel.additional_field1 == "value"
         assert mymodel.optional_field2 == 42
         assert isinstance(mymodel.id, int)
-
     """
 
     id: Optional[str] = Field(None, alias="_id")
