@@ -1,9 +1,12 @@
 from enum import Enum
-from typing import Optional, List, Union, Optional
+from typing import List, Union, Optional
 import pytz
+from datetime import datetime, timezone
+from dateutil import parser
 
 from pydantic import validator
 from fa_common import CamelModel
+from fa_common.storage import File
 
 # from fa_common.db import DocumentDBModel
 
@@ -13,6 +16,13 @@ class ModuleType(str, Enum):
     ASYNC = "async"  # Is executed via gitlab ci
 
 
+class JobAction(str, Enum):
+    PLAY = "play"
+    RETRY = "retry"
+    DELETE = "delete"
+    CANCEL = "cancel"
+
+
 class JobStatus(str, Enum):
     NOT_SET = ""
     RECEIVED = "RECEIVED"
@@ -39,8 +49,8 @@ class ScidraModule(CamelModel):
     input_schema: str = ""
     output_schema: str = ""
     input_files: List[FileFieldDescription] = []
-    cpu_limit: int = 4
-    cpu_request: int = 1
+    cpu_limit: str = "4000m"
+    cpu_request: str = "1000m"
     memory_limit_gb: int = 8
     memory_request_gb: int = 2
 
@@ -52,15 +62,24 @@ class JobRun(CamelModel):
     started_at: Optional[str]
     finished_at: Optional[str]
     duration: Optional[int]
-    name: Optional[str]
+    name: str = ""
     stage: Optional[str]
     output: Optional[Union[List, dict]]
-    # output_files:
+    files: Optional[List[File]]
     log: Optional[bytes]
 
     class Config:
         use_enum_values = True
 
+    def get_compare_time(self) -> datetime:
+        if self.started_at is None:
+            if self.status not in ["failed", "canceled", "skipped"]:
+                return datetime.min.replace(tzinfo=timezone.utc)
+            else:
+                return datetime.now(tz=timezone.utc)
+        else:
+            return parser.isoparse(self.started_at)
+
 
 class WorkflowRun(CamelModel):
     """Equivilant to  gitlab pipeline"""
@@ -71,6 +90,7 @@ class WorkflowRun(CamelModel):
     commit_id: str
     status: str = ""
     jobs: List[JobRun] = []
+    hidden_jobs: Optional[List[JobRun]] = []
     started_at: Optional[str]
     finished_at: Optional[str]
     duration: Optional[int]
@@ -97,6 +117,7 @@ class WorkflowRun(CamelModel):
 class WorkflowProject(CamelModel):
     name: str
     user_id: str
+    bucket_id: str
     gitlab_project_id: int
     created: Optional[str]
     timezone: str = "UTC"
