@@ -1,5 +1,8 @@
 import os
 import pytest
+import json
+import copy
+import time
 
 from fa_common import create_app, start_app, utils, force_sync
 from fa_common.workflow import (
@@ -10,9 +13,18 @@ from fa_common.workflow import (
     create_workflow_project,
     WorkflowProject,
     get_workflow_client,
+    get_workflow,
+    delete_workflow,
+    job_action,
+    JobAction,
 )
 from fa_common.storage import File
-from .conftest import get_env_file, TEST_GITLAB_PROJECT, TEST_GITLAB_BRANCH
+from .conftest import (
+    get_env_file,
+    TEST_GITLAB_PROJECT,
+    TEST_GITLAB_BRANCH,
+    TEST_USER_BUCKET,
+)
 
 dirname = os.path.dirname(__file__)
 test_data_path = os.path.join(dirname, "data")
@@ -25,7 +37,7 @@ utils.current_app = app
 @pytest.mark.asyncio
 async def test_gitlab_create(ensure_no_test_gitlab):
     workflow_project = await create_workflow_project(
-        TEST_GITLAB_PROJECT, TEST_GITLAB_BRANCH
+        TEST_GITLAB_PROJECT, TEST_GITLAB_BRANCH, TEST_USER_BUCKET
     )
 
     assert workflow_project.gitlab_project_id > 0
@@ -34,14 +46,9 @@ async def test_gitlab_create(ensure_no_test_gitlab):
 
 @pytest.mark.asyncio
 async def test_job_create(ensure_test_gitlab):
-    project_id = ensure_test_gitlab
-    assert project_id > 0
 
-    project = WorkflowProject(
-        name=TEST_GITLAB_BRANCH,
-        user_id=TEST_GITLAB_PROJECT,
-        gitlab_project_id=project_id,
-    )
+    project = ensure_test_gitlab
+    assert project.gitlab_project_id > 0
 
     module = ScidraModule(
         name="noise-detection",
@@ -64,37 +71,34 @@ async def test_job_create(ensure_test_gitlab):
         )
     ]
 
-    job_run = await run_job(
+    work_run = await run_job(
         project,
         "Sync Unit Test",
         module,
         job_data,
         runner="csiro-swarm",
+        upload=False,
         files=files,
         sync=True,
     )
 
-    assert job_run.status == "success"
-    assert job_run.output is not None
+    assert work_run.status == "success"
+    assert work_run.jobs[0].output is not None
 
-    job_run2 = await get_job_run(project_id, job_run.id, False)
+    job_run2 = await get_job_run(
+        project.user_id, TEST_USER_BUCKET, work_run.jobs[0].id, False,
+    )
 
-    assert job_run2.id == job_run.id
+    assert job_run2.id == work_run.jobs[0].id
 
-    job_logs = await get_job_log(project_id, job_run.id)
+    job_logs = await get_job_log(project.user_id, job_run2.id)
     assert job_logs is not None
 
 
 @pytest.mark.asyncio
 async def test_job_create_async(ensure_test_gitlab):
-    project_id = ensure_test_gitlab
-    assert project_id > 0
-
-    project = WorkflowProject(
-        name=TEST_GITLAB_BRANCH,
-        user_id=TEST_GITLAB_PROJECT,
-        gitlab_project_id=project_id,
-    )
+    project = ensure_test_gitlab
+    assert project.gitlab_project_id > 0
 
     module = ScidraModule(
         name="noise-detection",
@@ -117,32 +121,25 @@ async def test_job_create_async(ensure_test_gitlab):
         )
     ]
 
-    job_run = await run_job(
+    work_run = await run_job(
         project, "Async Unit Test", module, job_data, runner="csiro-swarm", files=files
     )
 
-    job_run2 = await get_job_run(project_id, job_run.id)
+    job_run2 = await get_job_run(project.user_id, TEST_USER_BUCKET, work_run.jobs[0].id)
 
-    assert job_run2.id == job_run.id
+    assert job_run2.id == work_run.jobs[0].id
 
 
 @pytest.mark.asyncio
 async def test_large_job_create_async(ensure_test_gitlab):
-    project_id = ensure_test_gitlab
-    assert project_id > 0
-
-    project = WorkflowProject(
-        name=TEST_GITLAB_BRANCH,
-        user_id=TEST_GITLAB_PROJECT,
-        gitlab_project_id=project_id,
-        timezone="Australia/Perth",
-    )
+    project = ensure_test_gitlab
+    assert project.gitlab_project_id > 0
 
     module = ScidraModule(
         name="galei-inversion",
         docker_image="registry.gitlab.com/csiro-geoanalytics/gpt/modules/galei-inversion-module:latest",
-        cpu_limit=4,
-        cpu_request=2,
+        cpu_limit="4000m",
+        cpu_request="2000m",
         memory_limit_gb=16,
         memory_request_gb=4,
     )
@@ -156,7 +153,73 @@ async def test_large_job_create_async(ensure_test_gitlab):
 
 
 @pytest.mark.asyncio
-async def test_delete_workflow_project():
+async def test_multi_job_retry(ensure_test_gitlab, ensure_test_bucket):
+    client = ensure_test_bucket
+
+    project = ensure_test_gitlab
+    assert project.gitlab_project_id > 0
+    module = ScidraModule(
+        name="sensi-module",
+        docker_image="registry.gitlab.com/csiro-geoanalytics/gpt/modules/sensi-seismic-module:latest",
+        cpu_limit="1000m",
+        cpu_request="500m",
+        memory_limit_gb=4,
+        memory_request_gb=2,
+    )
+
+    with open(os.path.join(dirname, "data", "test_sensi.json")) as json_file:
+        sensi_data = json.load(json_file)
+
+    depth_list = sensi_data["config"]["hypocenterDepth"]
+
+    params_list = []
+    for depth in depth_list:
+        params = copy.deepcopy(sensi_data)
+        params["config"]["hypocenterDepth"] = depth
+        params_list.append(params)
+
+    work_run = await run_job(
+        project,
+        f"test_multi_job_create_async Test",
+        module,
+        params_list,
+        # runner="csiro-easi-hub",
+        runner="csiro-swarm",
+        files=[],
+        upload=True,
+    )
+
+    rt_job = work_run.jobs[1]
+    rt_job = await job_action(TEST_GITLAB_PROJECT, rt_job.id, JobAction.CANCEL)
+    assert rt_job.status == "canceled"
+    new_job = await job_action(TEST_GITLAB_PROJECT, rt_job.id, JobAction.RETRY)
+
+    while work_run.finished_at is None:
+        time.sleep(8)
+        work_run = await get_workflow(
+            TEST_GITLAB_PROJECT, TEST_USER_BUCKET, work_run.id
+        )
+
+    assert work_run.hidden_jobs is not None and work_run.hidden_jobs[0].id == rt_job.id
+    assert work_run.jobs[1].id == new_job.id  # Assert order remains the same
+    assert work_run.status == "success"
+    assert await client.file_exists(
+        TEST_USER_BUCKET, f"job_data/{work_run.id}/{work_run.jobs[0].id}/outputs.json",
+    )
+    job_run = await get_job_run(
+        TEST_GITLAB_PROJECT, TEST_USER_BUCKET, work_run.jobs[0].id
+    )
+    assert job_run.output is not None
+    assert len(job_run.files) > 0
+
+    await delete_workflow(TEST_GITLAB_PROJECT, TEST_USER_BUCKET, work_run.id)
+    assert not await client.file_exists(
+        TEST_USER_BUCKET, f"job_data/{work_run.id}/{work_run.jobs[0].id}/outputs.json",
+    )
+
+
+@pytest.mark.asyncio
+async def test_delete_workflow_project(ensure_test_gitlab):
     client = get_workflow_client()
     try:
         project = await client._get_project_by_name(TEST_GITLAB_PROJECT)
